==> ghc-9.12.2.20251209-src.tar.xz: ghc-9.12.2.20251209/libraries/ghc-internal/include/RtsIfaceSymbols.h <==
// See Note [RTS/ghc-internal interface].

#if defined(mingw32_HOST_OS)
CLOSURE(GHCziInternalziEventziWindows, processRemoteCompletion_closure)
#else
UNDEF_CLOSURE(GHCziInternalziEventziWindows, processRemoteCompletion_closure)
#endif
CLOSURE(GHCziInternalziTopHandler, runIO_closure)
CLOSURE(GHCziInternalziTopHandler, runNonIO_closure)
PRIMCLOSURE(GHCziTuple, Z0T_closure)
PRIMCLOSURE(GHCziTypes, True_closure)
PRIMCLOSURE(GHCziTypes, False_closure)
CLOSURE(GHCziInternalziPack, unpackCString_closure)
CLOSURE(GHCziInternalziWeakziFinalizze, runFinalizzerBatch_closure)
CLOSURE(GHCziInternalziIOziException, stackOverflow_closure)
CLOSURE(GHCziInternalziIOziException, heapOverflow_closure)
CLOSURE(GHCziInternalziIOPort, doubleReadException_closure)
CLOSURE(GHCziInternalziIOziException, allocationLimitExceeded_closure)
CLOSURE(GHCziInternalziIOziException, blockedIndefinitelyOnMVar_closure)
CLOSURE(GHCziInternalziIOziException, blockedIndefinitelyOnSTM_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactFunction_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactPinned_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactMutable_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, nonTermination_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, nestedAtomically_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, noMatchingContinuationPrompt_closure)
#if defined(mingw32_HOST_OS)
UNDEF_CLOSURE(GHCziInternalziEventziThread, blockedOnBadFD_closure)
#else
CLOSURE(GHCziInternalziEventziThread, blockedOnBadFD_closure)
#endif
CLOSURE(GHCziInternalziConcziSync, runSparks_closure)
CLOSURE(GHCziInternalziConcziIO, ensureIOManagerIsRunning_closure)
CLOSURE(GHCziInternalziConcziIO, interruptIOManager_closure)
CLOSURE(GHCziInternalziConcziIO, ioManagerCapabilitiesChanged_closure)
CLOSURE(GHCziInternalziConcziSignal, runHandlersPtr_closure)
CLOSURE(GHCziInternalziTopHandler, flushStdHandles_closure)
CLOSURE(GHCziInternalziTopHandler, runMainIO_closure)
PRIM_INFO_TBL(GHCziTypes, Czh_con_info)
PRIM_INFO_TBL(GHCziTypes, Izh_con_info)
PRIM_INFO_TBL(GHCziTypes, Fzh_con_info)
PRIM_INFO_TBL(GHCziTypes, Dzh_con_info)
PRIM_INFO_TBL(GHCziTypes, Wzh_con_info)
PRIMCLOSURE(GHCziPrimziPanic, absentSumFieldError_closure)
INFO_TBL(GHCziInternalziPtr, Ptr_con_info)
INFO_TBL(GHCziInternalziPtr, FunPtr_con_info)
INFO_TBL(GHCziInternalziInt, I8zh_con_info)
INFO_TBL(GHCziInternalziInt, I16zh_con_info)
INFO_TBL(GHCziInternalziInt, I32zh_con_info)
INFO_TBL(GHCziInternalziInt, I64zh_con_info)
INFO_TBL(GHCziInternalziWord, W8zh_con_info)
INFO_TBL(GHCziInternalziWord, W16zh_con_info)
INFO_TBL(GHCziInternalziWord, W32zh_con_info)
INFO_TBL(GHCziInternalziWord, W64zh_con_info)
INFO_TBL(GHCziInternalziStable, StablePtr_con_info)
CLOSURE(GHCziInternalziStackziCloneStack, StackSnapshot_closure)
CLOSURE(GHCziInternalziExceptionziType, divZZeroException_closure)
CLOSURE(GHCziInternalziExceptionziType, underflowException_closure)
CLOSURE(GHCziInternalziExceptionziType, overflowException_closure)
PRIM_INFO_TBL(GHCziCString, unpackCStringzh_info)
PRIM_INFO_TBL(GHCziCString, unpackCStringUtf8zh_info)
#if defined(wasm32_HOST_ARCH) && defined(__PIC__)
CLOSURE(GHCziInternalziWasmziPrimziImports, raiseJSException_closure)
INFO_TBL(GHCziInternalziWasmziPrimziTypes, JSVal_con_info)
CLOSURE(GHCziInternalziWasmziPrimziConcziInternal, threadDelay_closure)
#endif

==> ghc-9.14.1-src.tar.xz: ghc-9.14.1/libraries/ghc-internal/include/RtsIfaceSymbols.h <==
// See Note [RTS/ghc-internal interface].

#if defined(mingw32_HOST_OS)
CLOSURE(GHCziInternalziEventziWindows, processRemoteCompletion_closure)
#else
UNDEF_CLOSURE(GHCziInternalziEventziWindows, processRemoteCompletion_closure)
#endif
CLOSURE(GHCziInternalziTopHandler, runIO_closure)
CLOSURE(GHCziInternalziTopHandler, runNonIO_closure)
CLOSURE(GHCziInternalziTuple, Z0T_closure)
CLOSURE(GHCziInternalziTypes, True_closure)
CLOSURE(GHCziInternalziTypes, False_closure)
CLOSURE(GHCziInternalziPack, unpackCString_closure)
CLOSURE(GHCziInternalziWeakziFinalizze, runFinalizzerBatch_closure)
CLOSURE(GHCziInternalziIOziException, stackOverflow_closure)
CLOSURE(GHCziInternalziIOziException, heapOverflow_closure)
CLOSURE(GHCziInternalziIOziException, allocationLimitExceeded_closure)
CLOSURE(GHCziInternalziIOziException, blockedIndefinitelyOnMVar_closure)
CLOSURE(GHCziInternalziIOziException, blockedIndefinitelyOnSTM_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactFunction_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactPinned_closure)
CLOSURE(GHCziInternalziIOziException, cannotCompactMutable_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, nonTermination_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, nestedAtomically_closure)
CLOSURE(GHCziInternalziControlziExceptionziBase, noMatchingContinuationPrompt_closure)
#if defined(mingw32_HOST_OS)
UNDEF_CLOSURE(GHCziInternalziEventziThread, blockedOnBadFD_closure)
#else
CLOSURE(GHCziInternalziEventziThread, blockedOnBadFD_closure)
#endif
CLOSURE(GHCziInternalziConcziSync, runSparks_closure)
CLOSURE(GHCziInternalziConcziIO, ensureIOManagerIsRunning_closure)
CLOSURE(GHCziInternalziConcziIO, interruptIOManager_closure)
CLOSURE(GHCziInternalziConcziIO, ioManagerCapabilitiesChanged_closure)
CLOSURE(GHCziInternalziConcziSignal, runHandlersPtr_closure)
CLOSURE(GHCziInternalziTopHandler, flushStdHandles_closure)
CLOSURE(GHCziInternalziTopHandler, runMainIO_closure)
INFO_TBL(GHCziInternalziTypes, Czh_con_info)
INFO_TBL(GHCziInternalziTypes, Izh_con_info)
INFO_TBL(GHCziInternalziTypes, Fzh_con_info)
INFO_TBL(GHCziInternalziTypes, Dzh_con_info)
INFO_TBL(GHCziInternalziTypes, Wzh_con_info)
CLOSURE(GHCziInternalziPrimziPanic, absentSumFieldError_closure)
CLOSURE(GHCziInternalziAllocationLimitHandler, runAllocationLimitHandler_closure)
INFO_TBL(GHCziInternalziPtr, Ptr_con_info)
INFO_TBL(GHCziInternalziPtr, FunPtr_con_info)
INFO_TBL(GHCziInternalziInt, I8zh_con_info)
INFO_TBL(GHCziInternalziInt, I16zh_con_info)
INFO_TBL(GHCziInternalziInt, I32zh_con_info)
INFO_TBL(GHCziInternalziInt, I64zh_con_info)
INFO_TBL(GHCziInternalziWord, W8zh_con_info)
INFO_TBL(GHCziInternalziWord, W16zh_con_info)
INFO_TBL(GHCziInternalziWord, W32zh_con_info)
INFO_TBL(GHCziInternalziWord, W64zh_con_info)
INFO_TBL(GHCziInternalziStable, StablePtr_con_info)
CLOSURE(GHCziInternalziStackziCloneStack, StackSnapshot_closure)
CLOSURE(GHCziInternalziExceptionziType, divZZeroException_closure)
CLOSURE(GHCziInternalziExceptionziType, underflowException_closure)
CLOSURE(GHCziInternalziExceptionziType, overflowException_closure)
INFO_TBL(GHCziInternalziCString, unpackCStringzh_info)
INFO_TBL(GHCziInternalziCString, unpackCStringUtf8zh_info)
#if defined(wasm32_HOST_ARCH) && defined(__PIC__)
CLOSURE(GHCziInternalziWasmziPrimziImports, raiseJSException_closure)
INFO_TBL(GHCziInternalziWasmziPrimziTypes, JSVal_con_info)
CLOSURE(GHCziInternalziWasmziPrimziConcziInternal, threadDelay_closure)
#endif
